==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_coupon.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_coupon.lang.inc.php 2019-08-29
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2019 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'ERROR_INVALID_FINISDATE_COUPON'               => 'Dieser Gutschein ist nicht mehr gültig',
    'ERROR_INVALID_STARTDATE_COUPON'               => 'Dieser Gutschein ist noch nicht verfügbar',
    'ERROR_INVALID_USES_COUPON'                    => 'Dieser Gutschein kann nur ',
    'ERROR_INVALID_USES_USER_COUPON'               => 'Die maximale Nutzung dieses Gutscheines wurde erreicht.',
    'ERROR_NO_INVALID_REDEEM_COUPON'               => 'Ungültiger Gutscheincode',
    'MODULE_ORDER_TOTAL_COUPON_CALC_TAX_DESC'      => 'MwSt. neu berechnen',
    'MODULE_ORDER_TOTAL_COUPON_CALC_TAX_TITLE'     => 'MwSt. neu berechnen',
    'MODULE_ORDER_TOTAL_COUPON_DESCRIPTION'        => 'Rabattcoupon',
    'MODULE_ORDER_TOTAL_COUPON_HEADER'             => 'Gutscheine/Rabattcoupons',
    'MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING_DESC'  => 'Versandkosten an den Warenwert anrechnen',
    'MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING_TITLE' => 'Inklusive Versandkosten',
    'MODULE_ORDER_TOTAL_COUPON_INC_TAX_DESC'       => 'MwSt. an den Warenwert anrechnen',
    'MODULE_ORDER_TOTAL_COUPON_INC_TAX_TITLE'      => 'Inklusive MwSt.',
    'MODULE_ORDER_TOTAL_COUPON_SHOW_INFO_DESC'     => 'Coupondetails im Warenkorb anzeigen?',
    'MODULE_ORDER_TOTAL_COUPON_SHOW_INFO_TITLE'    => 'Coupondetails anzeigen',
    'MODULE_ORDER_TOTAL_COUPON_SORT_ORDER_DESC'    => 'Anzeigereihenfolge.',
    'MODULE_ORDER_TOTAL_COUPON_SORT_ORDER_TITLE'   => 'Sortierreihenfolge',
    'MODULE_ORDER_TOTAL_COUPON_STATUS_DESC'        => 'Möchten Sie den Wert des Rabattcoupons anzeigen?',
    'MODULE_ORDER_TOTAL_COUPON_STATUS_TITLE'       => 'Wert anzeigen',
    'MODULE_ORDER_TOTAL_COUPON_TAX_CLASS_DESC'     => 'Folgenden MwSt.-Satz benutzen, wenn Sie den Rabattcoupon als Gutschrift verwenden.',
    'MODULE_ORDER_TOTAL_COUPON_TAX_CLASS_TITLE'    => 'MwSt.-Satz',
    'MODULE_ORDER_TOTAL_COUPON_TITLE'              => 'Rabattcoupon',
    'MODULE_ORDER_TOTAL_COUPON_USER_PROMPT'        => '',
    'REDEEMED_COUPON'                              => 'ein Gutschein über ',
    'REDEEMED_MIN_ORDER'                           => 'für Waren über ',
    'REDEEMED_RESTRICTIONS'                        => ' [Artikel-/Kategorie-Einschränkungen]',
    'SHIPPING_NOT_INCLUDED'                        => ' [Versand nicht enthalten]',
    'TAX_NOT_INCLUDED'                             => ' [MwSt. nicht enthalten]',
    'TEXT_ENTER_COUPON_CODE'                       => 'Geben Sie hier Ihren Gutscheincode ein &nbsp;&nbsp;',
    'TIMES'                                        => ' mal benutzt werden.',
    'rebate'                                       => 'Nachlass',
    'shipping_cost'                                => 'Versandkosten',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_coupon.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_coupon.lang.inc.php 2019-08-29
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2019 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'ERROR_INVALID_FINISDATE_COUPON'               => 'Dieser Gutschein ist nicht mehr gültig',
    'ERROR_INVALID_STARTDATE_COUPON'               => 'Dieser Gutschein ist noch nicht verfügbar',
    'ERROR_INVALID_USES_COUPON'                    => 'Dieser Gutschein kann nur ',
    'ERROR_INVALID_USES_USER_COUPON'               => 'Die maximale Nutzung dieses Gutscheines wurde erreicht.',
    'ERROR_NO_INVALID_REDEEM_COUPON'               => 'Ungültiger Gutscheincode',
    'MODULE_ORDER_TOTAL_COUPON_CALC_TAX_DESC'      => 'MwSt. neu berechnen',
    'MODULE_ORDER_TOTAL_COUPON_CALC_TAX_TITLE'     => 'MwSt. neu berechnen',
    'MODULE_ORDER_TOTAL_COUPON_DESCRIPTION'        => 'Rabattcoupon',
    'MODULE_ORDER_TOTAL_COUPON_HEADER'             => 'Gutscheine/Rabattcoupons',
    'MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING_DESC'  => 'Versandkosten an den Warenwert anrechnen',
    'MODULE_ORDER_TOTAL_COUPON_INC_SHIPPING_TITLE' => 'Inklusive Versandkosten',
    'MODULE_ORDER_TOTAL_COUPON_INC_TAX_DESC'       => 'MwSt. an den Warenwert anrechnen',
    'MODULE_ORDER_TOTAL_COUPON_INC_TAX_TITLE'      => 'Inklusive MwSt.',
    'MODULE_ORDER_TOTAL_COUPON_SHOW_INFO_DESC'     => 'Coupondetails im Warenkorb anzeigen?',
    'MODULE_ORDER_TOTAL_COUPON_SHOW_INFO_TITLE'    => 'Coupondetails anzeigen',
    'MODULE_ORDER_TOTAL_COUPON_SORT_ORDER_DESC'    => 'Anzeigereihenfolge.',
    'MODULE_ORDER_TOTAL_COUPON_SORT_ORDER_TITLE'   => 'Sortierreihenfolge',
    'MODULE_ORDER_TOTAL_COUPON_STATUS_DESC'        => 'Möchtest du den Wert des Rabattcoupons anzeigen?',
    'MODULE_ORDER_TOTAL_COUPON_STATUS_TITLE'       => 'Wert anzeigen',
    'MODULE_ORDER_TOTAL_COUPON_TAX_CLASS_DESC'     => 'Folgenden MwSt.-Satz benutzen, wenn du den Rabattcoupon als Gutschrift verwendest.',
    'MODULE_ORDER_TOTAL_COUPON_TAX_CLASS_TITLE'    => 'MwSt.-Satz',
    'MODULE_ORDER_TOTAL_COUPON_TITLE'              => 'Rabattcoupon',
    'MODULE_ORDER_TOTAL_COUPON_USER_PROMPT'        => '',
    'REDEEMED_COUPON'                              => 'ein Gutschein über ',
    'REDEEMED_MIN_ORDER'                           => 'für Waren über ',
    'REDEEMED_RESTRICTIONS'                        => ' [Artikel-/Kategorie-Einschränkungen]',
    'SHIPPING_NOT_INCLUDED'                        => ' [Versand nicht enthalten]',
    'TAX_NOT_INCLUDED'                             => ' [MwSt. nicht enthalten]',
    'TEXT_ENTER_COUPON_CODE'                       => 'Geben Sie hier Ihren Gutscheincode ein &nbsp;&nbsp;',
    'TIMES'                                        => ' mal benutzt werden.',
    'rebate'                                       => 'Nachlass',
    'shipping_cost'                                => 'Versandkosten',
];
